#!/usr/bin/perl -w
#
# Register all projects in the project-data/ directory
# in the known-projects.xml file
#

use strict;
use Date::Calc;
use XML::Simple;
use Data::Dumper;

my $self          = 'fci-update-known-projects.pl';
my $version       = '0.1';
my $verbose       = 1; # default: 0

my $wwwroot       = '/var/www/fci-dev/';
my $xml_file      = '/var/www/fci-dev/xml-data/known-projects.xml';
my $project_dir   = '/var/www/fci-dev/project-data/';
        
my ($year,$month,$day,$hour,$min,$sec) = Date::Calc::Today_and_Now();

$month = '0'.$month if(length($month) == 1);
$day   = '0'.$day   if(length($day)   == 1);
$hour  = '0'.$hour  if(length($hour)  == 1);
$min   = '0'.$min   if(length($min)   == 1);
$sec   = '0'.$sec   if(length($sec)   == 1);

my $date = "$year-$month-$day";
my $time = "$hour:$min:$sec";

if(!-r $xml_file) {
	print "Cannot read known-projects.xml file!\n";	
	exit;
}

my $projects = XMLin( $xml_file,
                      KeyAttr    => { project => 'number', image => 'type' },
		      ForceArray => [ 'project', 'image' ],
		      KeepRoot   => 1,
                    ) || die $@;

print Dumper($projects);
exit;

if(-r $project_dir) {
	my $known_projects = {};

	opendir(DIR, $project_dir) || die "Cannot opendir: $project_dir ($!)";
	foreach(readdir DIR) {
		#p1234.gif
		#p1234.jpg
		#p1234.pdb
		#p1234.xyz
		#p1234.still.script
		#p1234.rotate.script
		#p1234.rotate.script
		
		if (/^p(\d+)\.(gif|jpg|pdb|xyz|(still|rotate)\.script)$/) {
			my $file    = $_;
			my $project = $1;
			my $ext     = $2;
			my $type    = $3;
			
			if($ext eq 'gif') {
				$known_projects->{known_projects}->{project}->{$project}->{image}->{rotate}->{file} 
					= 'project-data/'.$file;
			}
			elsif($ext eq 'jpg') {
				$known_projects->{known_projects}->{project}->{$project}->{image}->{still}->{file}
					= 'project-data/'.$file;
			}	
			elsif($ext eq 'pdb') {
				$known_projects->{known_projects}->{project}->{$project}->{pdb_file}
					= 'project-data/'.$file;
			}	
			elsif($ext eq 'xyz') {
				$known_projects->{known_projects}->{project}->{$project}->{xyz_file}
					= 'project-data/'.$file;
			}	
			elsif($ext =~ /^(still|rotate)\.script$/) {
				$known_projects->{known_projects}->{project}->{$project}->{image}->{$type}->{script}
					= 'project-data/'.$file;
			}	
			else {
				print "Que? $_\n";
			}
		}
	}
	closedir DIR;
	
	foreach my $project (keys %{$known_projects->{known_projects}->{project}}) {
		print "Project : $project\n";
		print "Name    : ";
		print $projects->{known_projects}->{project}->{$project}->{workunit_name};
		print "\n";
		print "\n";
		
		$known_projects->{known_projects}->{project}->{$project}->{workunit_name}
			= $projects->{known_projects}->{project}->{$project}->{workunit_name};

		$known_projects->{known_projects}->{project}->{$project}->{date_created}
			= $projects->{known_projects}->{project}->{$project}->{date_created};

		$known_projects->{known_projects}->{project}->{$project}->{date_updated}
			= $projects->{known_projects}->{project}->{$project}->{date_updated};
	}

	print Dumper($known_projects);
	
	# update the projects XML file
	print "Updating xml file: $xml_file\n" if($verbose);
	XMLout( $known_projects,
	        OutputFile => $xml_file.'.new',
		KeyAttr    => { project => 'number', image => 'type' },
		NoAttr     => 1,
		KeepRoot   => 1
      	) || die $@;
}
